OAuth2ErrorApiResponse

Enum OAuth2ErrorApiResponse 

pub enum OAuth2ErrorApiResponse {
    InvalidRequest {
        error_description: Option<String>,
    },
    InvalidGrant {
        error_description: Option<InvalidGrantError>,
    },
    InvalidClient {
        error_description: Option<String>,
    },
    UnauthorizedClient {
        error_description: Option<String>,
    },
    UnsupportedGrantType {
        error_description: Option<String>,
    },
    InvalidScope {
        error_description: Option<String>,
    },
    InvalidTarget {
        error_description: Option<String>,
    },
}
Per RFC 6749 Section 5.2, these are the standard error responses for OAuth 2.0 token requests. https://datatracker.ietf.org/doc/html/rfc6749#section-5.2

Variants



InvalidRequest

Invalid request error, typically due to missing parameters for a specific credential flow. Ex. password is required.

Fields

error_description: Option<String>

The optional error description for invalid request errors.



InvalidGrant

Invalid grant error, typically due to invalid credentials.

Fields

error_description: Option<InvalidGrantError>

The optional error description for invalid grant errors.



InvalidClient

Invalid client error, typically due to an invalid client secret or client ID.

Fields

error_description: Option<String>

The optional error description for invalid client errors.



UnauthorizedClient

Unauthorized client error, typically due to an unauthorized client.

Fields

error_description: Option<String>

The optional error description for unauthorized client errors.



UnsupportedGrantType

Unsupported grant type error, typically due to an unsupported credential flow.

Fields

error_description: Option<String>

The optional error description for unsupported grant type errors.



InvalidScope

Invalid scope error, typically due to an invalid scope requested.

Fields

error_description: Option<String>

The optional error description for invalid scope errors.



InvalidTarget

Invalid target error which is shown if the requested resource is invalid, missing, unknown, or malformed.

Fields

error_description: Option<String>

The optional error description for invalid target errors.