pub(crate) struct UserDecryptionOptionsApiResponse {
pub master_password_unlock: Option<MasterPasswordUnlockResponseModel>,
pub trusted_device_option: Option<TrustedDeviceUserDecryptionOptionApiResponse>,
pub key_connector_option: Option<KeyConnectorUserDecryptionOptionApiResponse>,
pub webauthn_prf_option: Option<WebAuthnPrfUserDecryptionOptionApiResponse>,
}Expand description
Provides user decryption options used to unlock user’s vault.
Fields
master_password_unlock: Option<MasterPasswordUnlockResponseModel>Contains information needed to unlock user’s vault with master password. None when user does not have a master password.
trusted_device_option: Option<TrustedDeviceUserDecryptionOptionApiResponse>Trusted Device Decryption Option.
key_connector_option: Option<KeyConnectorUserDecryptionOptionApiResponse>Key Connector Decryption Option. This option is mutually exlusive with the Trusted Device option as you must configure one or the other in the Organization SSO configuration.
webauthn_prf_option: Option<WebAuthnPrfUserDecryptionOptionApiResponse>WebAuthn PRF Decryption Option.