pub(crate) struct LoginSuccessApiResponse {Show 17 fields
pub access_token: String,
pub expires_in: u64,
pub scope: String,
pub token_type: String,
pub refresh_token: Option<String>,
pub private_key: Option<String>,
pub account_keys: Option<PrivateKeysResponseModel>,
pub key: Option<String>,
pub two_factor_token: Option<String>,
pub kdf: Option<KdfType>,
pub kdf_iterations: Option<i32>,
pub kdf_memory: Option<i32>,
pub kdf_parallelism: Option<i32>,
pub force_password_reset: Option<bool>,
pub api_use_key_connector: Option<bool>,
pub user_decryption_options: Option<UserDecryptionOptionsApiResponse>,
pub master_password_policy: Option<MasterPasswordPolicyResponseModel>,
}Expand description
API response model for a successful login via the Identity API. OAuth 2.0 Successful Response RFC reference: https://datatracker.ietf.org/doc/html/rfc6749#section-5.1
Fields
access_token: StringThe access token string.
expires_in: u64The duration in seconds until the token expires.
scope: StringThe scope of the access token. OAuth 2.0 RFC reference: https://datatracker.ietf.org/doc/html/rfc6749#section-3.3
token_type: StringThe type of the token. This will be “Bearer” for send access tokens. OAuth 2.0 RFC reference: https://datatracker.ietf.org/doc/html/rfc6749#section-7.1
refresh_token: Option<String>The optional refresh token string. This token can be used to obtain new access tokens when the current one expires.
private_key: Option<String>The user key wrapped user private key
Deprecated in favor of the AccountKeys field but still present for backward
compatibility. and we can’t expose AccountKeys in our LoginSuccessResponse until we get
a PrivateKeysResponseModel SDK response model from KM with WASM / uniffi support.
TODO: PM-30222 - clean up the comment about not being able to expose AccountKeys once
we have a trait to convert PrivateKeysResponseModel to WrappedAccountCryptographicState
account_keys: Option<PrivateKeysResponseModel>The user’s asymmetric encryption keys and signature keys
key: Option<String>user_decryption_options.master_password_unlock insteadThe master key wrapped user key.
two_factor_token: Option<String>Two factor remember me token to be used for future requests to bypass 2FA prompts for a limited time.
kdf: Option<KdfType>user_decryption_options.master_password_unlock insteadMaster key derivation function type
kdf_iterations: Option<i32>user_decryption_options.master_password_unlock insteadMaster key derivation function iterations
kdf_memory: Option<i32>user_decryption_options.master_password_unlock insteadMaster key derivation function memory
kdf_parallelism: Option<i32>user_decryption_options.master_password_unlock insteadMaster key derivation function parallelism
force_password_reset: Option<bool>Indicates whether an admin has reset the user’s master password, requiring them to set a new password upon next login.
api_use_key_connector: Option<bool>Indicates whether the user uses Key Connector and if the client should have a locally configured Key Connector URL in their environment. Note: This is currently only applicable for client_credential grant type logins and is only expected to be relevant for the CLI
user_decryption_options: Option<UserDecryptionOptionsApiResponse>The user’s decryption options for their vault.
master_password_policy: Option<MasterPasswordPolicyResponseModel>If the user is subject to an organization master password policy, this field contains the requirements of that policy.